Description Usage Arguments Details Examples
Assigns numbers as names to columns of a data frame.
1 | give_col_numbers(x, prefix = "COL.")
|
x |
a data frame |
prefix |
template pattern character string |
We use string concatentation and coercion of integers to character type.
1 2 | ## rename the columns in an in-built R data set
give_col_numbers(zooper)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.