zooper: Zooper example data

Description Details

Description

A subset of iris used for example purposes and code testing.

Details

The data frame was created from the iris data set, the script is recorded in 'data-raw/DATASET.R'.

The structure of the data is an R data frame with 3 columns and 10 rows.


mdsumner/zooperdanke documentation built on Nov. 4, 2019, 6:23 p.m.