A subset of iris used for example purposes and code testing.
The data frame was created from the iris data set, the script is recorded in 'data-raw/DATASET.R'.
The structure of the data is an R data frame with 3 columns and 10 rows.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.